
#include "CondFormats/BTauObjects/src/headers.h"

#include <boost/serialization/base_object.hpp>
#include <boost/serialization/nvp.hpp>
#include <boost/serialization/export.hpp>

#include "CondFormats/Serialization/interface/Equal.h"
#include "CondFormats/Serialization/interface/Instantiate.h"

template <class Archive>
void BTagCalibration::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("tagger-", tagger_);
    ar & boost::serialization::make_nvp("data-", data_);
}
COND_SERIALIZATION_INSTANTIATE(BTagCalibration);

template <class Archive>
void BTagEntry::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("formula", formula);
    ar & boost::serialization::make_nvp("params", params);
}
COND_SERIALIZATION_INSTANTIATE(BTagEntry);

template <class Archive>
void BTagEntry::Parameters::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("operatingPoint", operatingPoint);
    ar & boost::serialization::make_nvp("measurementType", measurementType);
    ar & boost::serialization::make_nvp("sysType", sysType);
    ar & boost::serialization::make_nvp("jetFlavor", jetFlavor);
    ar & boost::serialization::make_nvp("etaMin", etaMin);
    ar & boost::serialization::make_nvp("etaMax", etaMax);
    ar & boost::serialization::make_nvp("ptMin", ptMin);
    ar & boost::serialization::make_nvp("ptMax", ptMax);
    ar & boost::serialization::make_nvp("discrMin", discrMin);
    ar & boost::serialization::make_nvp("discrMax", discrMax);
}
COND_SERIALIZATION_INSTANTIATE(BTagEntry::Parameters);

template <class Archive>
void CombinedSVCalibration::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("data", data);
}
COND_SERIALIZATION_INSTANTIATE(CombinedSVCalibration);

template <class Archive>
void CombinedSVCalibration::Entry::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("category", category);
    ar & boost::serialization::make_nvp("histogram", histogram);
}
COND_SERIALIZATION_INSTANTIATE(CombinedSVCalibration::Entry);

template <class Archive>
void CombinedSVCategoryData::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("JetEtaMax", JetEtaMax);
    ar & boost::serialization::make_nvp("JetEtaMin", JetEtaMin);
    ar & boost::serialization::make_nvp("JetPtMax", JetPtMax);
    ar & boost::serialization::make_nvp("JetPtMin", JetPtMin);
    ar & boost::serialization::make_nvp("PartonType", PartonType);
    ar & boost::serialization::make_nvp("TaggingVariable", TaggingVariable);
    ar & boost::serialization::make_nvp("VertexType", VertexType);
}
COND_SERIALIZATION_INSTANTIATE(CombinedSVCategoryData);

template <class Archive>
void CombinedTauTagCalibration::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("data", data);
}
COND_SERIALIZATION_INSTANTIATE(CombinedTauTagCalibration);

template <class Archive>
void CombinedTauTagCalibration::Entry::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("category", category);
    ar & boost::serialization::make_nvp("histogram", histogram);
}
COND_SERIALIZATION_INSTANTIATE(CombinedTauTagCalibration::Entry);

template <class Archive>
void CombinedTauTagCategoryData::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("truthmatched1orfake0candidates", truthmatched1orfake0candidates);
    ar & boost::serialization::make_nvp("theTagVar", theTagVar);
    ar & boost::serialization::make_nvp("signaltks-n", signaltks_n);
    ar & boost::serialization::make_nvp("EtMin", EtMin);
    ar & boost::serialization::make_nvp("EtMax", EtMax);
}
COND_SERIALIZATION_INSTANTIATE(CombinedTauTagCategoryData);

template <class Archive>
void TrackProbabilityCalibration::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("data", data);
}
COND_SERIALIZATION_INSTANTIATE(TrackProbabilityCalibration);

template <class Archive>
void TrackProbabilityCalibration::Entry::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("category", category);
    ar & boost::serialization::make_nvp("histogram", histogram);
}
COND_SERIALIZATION_INSTANTIATE(TrackProbabilityCalibration::Entry);

template <class Archive>
void TrackProbabilityCategoryData::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("pMin", pMin);
    ar & boost::serialization::make_nvp("pMax", pMax);
    ar & boost::serialization::make_nvp("etaMin", etaMin);
    ar & boost::serialization::make_nvp("etaMax", etaMax);
    ar & boost::serialization::make_nvp("nHitsMin", nHitsMin);
    ar & boost::serialization::make_nvp("nHitsMax", nHitsMax);
    ar & boost::serialization::make_nvp("nPixelHitsMin", nPixelHitsMin);
    ar & boost::serialization::make_nvp("nPixelHitsMax", nPixelHitsMax);
    ar & boost::serialization::make_nvp("chiMin", chiMin);
    ar & boost::serialization::make_nvp("chiMax", chiMax);
    ar & boost::serialization::make_nvp("withFirstPixel", withFirstPixel);
    ar & boost::serialization::make_nvp("trackQuality", trackQuality);
}
COND_SERIALIZATION_INSTANTIATE(TrackProbabilityCategoryData);

