
#include "CondFormats/GeometryObjects/src/headers.h"

#include <boost/serialization/base_object.hpp>
#include <boost/serialization/nvp.hpp>
#include <boost/serialization/export.hpp>

#include "CondFormats/Serialization/interface/Equal.h"
#include "CondFormats/Serialization/interface/Instantiate.h"

template <class Archive>
void CSCRecoDigiParameters::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("pUserParOffset", pUserParOffset);
    ar & boost::serialization::make_nvp("pUserParSize", pUserParSize);
    ar & boost::serialization::make_nvp("pChamberType", pChamberType);
    ar & boost::serialization::make_nvp("pfupars", pfupars);
}
COND_SERIALIZATION_INSTANTIATE(CSCRecoDigiParameters);

template <class Archive>
void PCaloGeometry::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("m-translation", m_translation);
    ar & boost::serialization::make_nvp("m-dimension", m_dimension);
    ar & boost::serialization::make_nvp("m-indexes", m_indexes);
    ar & boost::serialization::make_nvp("m-dins", m_dins);
}
COND_SERIALIZATION_INSTANTIATE(PCaloGeometry);

template <class Archive>
void PGeometricDet::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("pgeomdets-", pgeomdets_);
}
COND_SERIALIZATION_INSTANTIATE(PGeometricDet);

template <class Archive>
void PGeometricDet::Item::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("-name", _name);
    ar & boost::serialization::make_nvp("-ns", _ns);
    ar & boost::serialization::make_nvp("-x", _x);
    ar & boost::serialization::make_nvp("-y", _y);
    ar & boost::serialization::make_nvp("-z", _z);
    ar & boost::serialization::make_nvp("-phi", _phi);
    ar & boost::serialization::make_nvp("-rho", _rho);
    ar & boost::serialization::make_nvp("-a11", _a11);
    ar & boost::serialization::make_nvp("-a12", _a12);
    ar & boost::serialization::make_nvp("-a13", _a13);
    ar & boost::serialization::make_nvp("-a21", _a21);
    ar & boost::serialization::make_nvp("-a22", _a22);
    ar & boost::serialization::make_nvp("-a23", _a23);
    ar & boost::serialization::make_nvp("-a31", _a31);
    ar & boost::serialization::make_nvp("-a32", _a32);
    ar & boost::serialization::make_nvp("-a33", _a33);
    ar & boost::serialization::make_nvp("-params0", _params0);
    ar & boost::serialization::make_nvp("-params1", _params1);
    ar & boost::serialization::make_nvp("-params2", _params2);
    ar & boost::serialization::make_nvp("-params3", _params3);
    ar & boost::serialization::make_nvp("-params4", _params4);
    ar & boost::serialization::make_nvp("-params5", _params5);
    ar & boost::serialization::make_nvp("-params6", _params6);
    ar & boost::serialization::make_nvp("-params7", _params7);
    ar & boost::serialization::make_nvp("-params8", _params8);
    ar & boost::serialization::make_nvp("-params9", _params9);
    ar & boost::serialization::make_nvp("-params10", _params10);
    ar & boost::serialization::make_nvp("-radLength", _radLength);
    ar & boost::serialization::make_nvp("-xi", _xi);
    ar & boost::serialization::make_nvp("-pixROCRows", _pixROCRows);
    ar & boost::serialization::make_nvp("-pixROCCols", _pixROCCols);
    ar & boost::serialization::make_nvp("-pixROCx", _pixROCx);
    ar & boost::serialization::make_nvp("-pixROCy", _pixROCy);
    ar & boost::serialization::make_nvp("-siliconAPVNum", _siliconAPVNum);
    ar & boost::serialization::make_nvp("-level", _level);
    ar & boost::serialization::make_nvp("-shape", _shape);
    ar & boost::serialization::make_nvp("-type", _type);
    ar & boost::serialization::make_nvp("-numnt", _numnt);
    ar & boost::serialization::make_nvp("-nt0", _nt0);
    ar & boost::serialization::make_nvp("-nt1", _nt1);
    ar & boost::serialization::make_nvp("-nt2", _nt2);
    ar & boost::serialization::make_nvp("-nt3", _nt3);
    ar & boost::serialization::make_nvp("-nt4", _nt4);
    ar & boost::serialization::make_nvp("-nt5", _nt5);
    ar & boost::serialization::make_nvp("-nt6", _nt6);
    ar & boost::serialization::make_nvp("-nt7", _nt7);
    ar & boost::serialization::make_nvp("-nt8", _nt8);
    ar & boost::serialization::make_nvp("-nt9", _nt9);
    ar & boost::serialization::make_nvp("-nt10", _nt10);
    ar & boost::serialization::make_nvp("-geographicalID", _geographicalID);
    ar & boost::serialization::make_nvp("-stereo", _stereo);
}
COND_SERIALIZATION_INSTANTIATE(PGeometricDet::Item);

template <class Archive>
void PGeometricDetExtra::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("pgdes-", pgdes_);
}
COND_SERIALIZATION_INSTANTIATE(PGeometricDetExtra);

template <class Archive>
void PGeometricDetExtra::Item::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("-geographicalId", _geographicalId);
    ar & boost::serialization::make_nvp("-volume", _volume);
    ar & boost::serialization::make_nvp("-density", _density);
    ar & boost::serialization::make_nvp("-weight", _weight);
    ar & boost::serialization::make_nvp("-copy", _copy);
    ar & boost::serialization::make_nvp("-material", _material);
}
COND_SERIALIZATION_INSTANTIATE(PGeometricDetExtra::Item);

template <class Archive>
void PTrackerParameters::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("pxb", pxb);
    ar & boost::serialization::make_nvp("pxf", pxf);
    ar & boost::serialization::make_nvp("tec", tec);
    ar & boost::serialization::make_nvp("tib", tib);
    ar & boost::serialization::make_nvp("tid", tid);
    ar & boost::serialization::make_nvp("tob", tob);
}
COND_SERIALIZATION_INSTANTIATE(PTrackerParameters);

template <class Archive>
void PTrackerParameters::PxbItem::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("layerStartBit", layerStartBit);
    ar & boost::serialization::make_nvp("ladderStartBit", ladderStartBit);
    ar & boost::serialization::make_nvp("moduleStartBit", moduleStartBit);
    ar & boost::serialization::make_nvp("layerMask", layerMask);
    ar & boost::serialization::make_nvp("ladderMask", ladderMask);
    ar & boost::serialization::make_nvp("moduleMask", moduleMask);
}
COND_SERIALIZATION_INSTANTIATE(PTrackerParameters::PxbItem);

template <class Archive>
void PTrackerParameters::PxfItem::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("sideStartBit", sideStartBit);
    ar & boost::serialization::make_nvp("diskStartBit", diskStartBit);
    ar & boost::serialization::make_nvp("bladeStartBit", bladeStartBit);
    ar & boost::serialization::make_nvp("panelStartBit", panelStartBit);
    ar & boost::serialization::make_nvp("moduleStartBit", moduleStartBit);
    ar & boost::serialization::make_nvp("sideMask", sideMask);
    ar & boost::serialization::make_nvp("diskMask", diskMask);
    ar & boost::serialization::make_nvp("bladeMask", bladeMask);
    ar & boost::serialization::make_nvp("panelMask", panelMask);
    ar & boost::serialization::make_nvp("moduleMask", moduleMask);
}
COND_SERIALIZATION_INSTANTIATE(PTrackerParameters::PxfItem);

template <class Archive>
void PTrackerParameters::TECItem::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("sideStartBit", sideStartBit);
    ar & boost::serialization::make_nvp("wheelStartBit", wheelStartBit);
    ar & boost::serialization::make_nvp("petal-fw-bwStartBit", petal_fw_bwStartBit);
    ar & boost::serialization::make_nvp("petalStartBit", petalStartBit);
    ar & boost::serialization::make_nvp("ringStartBit", ringStartBit);
    ar & boost::serialization::make_nvp("moduleStartBit", moduleStartBit);
    ar & boost::serialization::make_nvp("sterStartBit", sterStartBit);
    ar & boost::serialization::make_nvp("sideMask", sideMask);
    ar & boost::serialization::make_nvp("wheelMask", wheelMask);
    ar & boost::serialization::make_nvp("petal-fw-bwMask", petal_fw_bwMask);
    ar & boost::serialization::make_nvp("petalMask", petalMask);
    ar & boost::serialization::make_nvp("ringMask", ringMask);
    ar & boost::serialization::make_nvp("moduleMask", moduleMask);
    ar & boost::serialization::make_nvp("sterMask", sterMask);
}
COND_SERIALIZATION_INSTANTIATE(PTrackerParameters::TECItem);

template <class Archive>
void PTrackerParameters::TIBItem::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("layerStartBit", layerStartBit);
    ar & boost::serialization::make_nvp("str-fw-bwStartBit", str_fw_bwStartBit);
    ar & boost::serialization::make_nvp("str-int-extStartBit", str_int_extStartBit);
    ar & boost::serialization::make_nvp("strStartBit", strStartBit);
    ar & boost::serialization::make_nvp("moduleStartBit", moduleStartBit);
    ar & boost::serialization::make_nvp("sterStartBit", sterStartBit);
    ar & boost::serialization::make_nvp("layerMask", layerMask);
    ar & boost::serialization::make_nvp("str-fw-bwMask", str_fw_bwMask);
    ar & boost::serialization::make_nvp("str-int-extMask", str_int_extMask);
    ar & boost::serialization::make_nvp("strMask", strMask);
    ar & boost::serialization::make_nvp("moduleMask", moduleMask);
    ar & boost::serialization::make_nvp("sterMask", sterMask);
}
COND_SERIALIZATION_INSTANTIATE(PTrackerParameters::TIBItem);

template <class Archive>
void PTrackerParameters::TIDItem::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("sideStartBit", sideStartBit);
    ar & boost::serialization::make_nvp("wheelStartBit", wheelStartBit);
    ar & boost::serialization::make_nvp("ringStartBit", ringStartBit);
    ar & boost::serialization::make_nvp("module-fw-bwStartBit", module_fw_bwStartBit);
    ar & boost::serialization::make_nvp("moduleStartBit", moduleStartBit);
    ar & boost::serialization::make_nvp("sterStartBit", sterStartBit);
    ar & boost::serialization::make_nvp("sideMask", sideMask);
    ar & boost::serialization::make_nvp("wheelMask", wheelMask);
    ar & boost::serialization::make_nvp("ringMask", ringMask);
    ar & boost::serialization::make_nvp("module-fw-bwMask", module_fw_bwMask);
    ar & boost::serialization::make_nvp("moduleMask", moduleMask);
    ar & boost::serialization::make_nvp("sterMask", sterMask);
}
COND_SERIALIZATION_INSTANTIATE(PTrackerParameters::TIDItem);

template <class Archive>
void PTrackerParameters::TOBItem::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("layerStartBit", layerStartBit);
    ar & boost::serialization::make_nvp("rod-fw-bwStartBit", rod_fw_bwStartBit);
    ar & boost::serialization::make_nvp("rodStartBit", rodStartBit);
    ar & boost::serialization::make_nvp("moduleStartBit", moduleStartBit);
    ar & boost::serialization::make_nvp("sterStartBit", sterStartBit);
    ar & boost::serialization::make_nvp("layerMask", layerMask);
    ar & boost::serialization::make_nvp("rod-fw-bwMask", rod_fw_bwMask);
    ar & boost::serialization::make_nvp("rodMask", rodMask);
    ar & boost::serialization::make_nvp("moduleMask", moduleMask);
    ar & boost::serialization::make_nvp("sterMask", sterMask);
}
COND_SERIALIZATION_INSTANTIATE(PTrackerParameters::TOBItem);

template <class Archive>
void RecoIdealGeometry::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("pDetIds", pDetIds);
    ar & boost::serialization::make_nvp("pPars", pPars);
    ar & boost::serialization::make_nvp("pParsIndex", pParsIndex);
    ar & boost::serialization::make_nvp("pNumShapeParms", pNumShapeParms);
    ar & boost::serialization::make_nvp("strPars", strPars);
    ar & boost::serialization::make_nvp("sParsIndex", sParsIndex);
    ar & boost::serialization::make_nvp("sNumsParms", sNumsParms);
}
COND_SERIALIZATION_INSTANTIATE(RecoIdealGeometry);

