
#include "CondFormats/RunInfo/src/headers.h"

#include <boost/serialization/base_object.hpp>
#include <boost/serialization/nvp.hpp>
#include <boost/serialization/export.hpp>

#include "CondFormats/Serialization/interface/Equal.h"
#include "CondFormats/Serialization/interface/Instantiate.h"

template <class Archive>
void FillInfo::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("m-isData", m_isData);
    ar & boost::serialization::make_nvp("m-lhcFill", m_lhcFill);
    ar & boost::serialization::make_nvp("m-bunches1", m_bunches1);
    ar & boost::serialization::make_nvp("m-bunches2", m_bunches2);
    ar & boost::serialization::make_nvp("m-collidingBunches", m_collidingBunches);
    ar & boost::serialization::make_nvp("m-targetBunches", m_targetBunches);
    ar & boost::serialization::make_nvp("m-fillType", m_fillType);
    ar & boost::serialization::make_nvp("m-particles1", m_particles1);
    ar & boost::serialization::make_nvp("m-particles2", m_particles2);
    ar & boost::serialization::make_nvp("m-crossingAngle", m_crossingAngle);
    ar & boost::serialization::make_nvp("m-betastar", m_betastar);
    ar & boost::serialization::make_nvp("m-intensity1", m_intensity1);
    ar & boost::serialization::make_nvp("m-intensity2", m_intensity2);
    ar & boost::serialization::make_nvp("m-energy", m_energy);
    ar & boost::serialization::make_nvp("m-createTime", m_createTime);
    ar & boost::serialization::make_nvp("m-beginTime", m_beginTime);
    ar & boost::serialization::make_nvp("m-endTime", m_endTime);
    ar & boost::serialization::make_nvp("m-injectionScheme", m_injectionScheme);
    ar & boost::serialization::make_nvp("m-bunchConfiguration1", m_bunchConfiguration1);
    ar & boost::serialization::make_nvp("m-bunchConfiguration2", m_bunchConfiguration2);
}
COND_SERIALIZATION_INSTANTIATE(FillInfo);

template <class Archive>
void L1TriggerScaler::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("m-run", m_run);
    ar & boost::serialization::make_nvp("m-lumisegment", m_lumisegment);
    ar & boost::serialization::make_nvp("m-runnumber", m_runnumber);
}
COND_SERIALIZATION_INSTANTIATE(L1TriggerScaler);

template <class Archive>
void L1TriggerScaler::Lumi::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("m-runnumber", m_runnumber);
    ar & boost::serialization::make_nvp("m-lumi-id", m_lumi_id);
    ar & boost::serialization::make_nvp("m-start-time", m_start_time);
    ar & boost::serialization::make_nvp("m-string-format", m_string_format);
    ar & boost::serialization::make_nvp("m-rn", m_rn);
    ar & boost::serialization::make_nvp("m-lumisegment", m_lumisegment);
    ar & boost::serialization::make_nvp("m-date", m_date);
    ar & boost::serialization::make_nvp("m-GTAlgoCounts", m_GTAlgoCounts);
    ar & boost::serialization::make_nvp("m-GTAlgoRates", m_GTAlgoRates);
    ar & boost::serialization::make_nvp("m-GTAlgoPrescaling", m_GTAlgoPrescaling);
    ar & boost::serialization::make_nvp("m-GTTechCounts", m_GTTechCounts);
    ar & boost::serialization::make_nvp("m-GTTechRates", m_GTTechRates);
    ar & boost::serialization::make_nvp("m-GTTechPrescaling", m_GTTechPrescaling);
    ar & boost::serialization::make_nvp("m-GTPartition0TriggerCounts", m_GTPartition0TriggerCounts);
    ar & boost::serialization::make_nvp("m-GTPartition0TriggerRates", m_GTPartition0TriggerRates);
    ar & boost::serialization::make_nvp("m-GTPartition0DeadTime", m_GTPartition0DeadTime);
    ar & boost::serialization::make_nvp("m-GTPartition0DeadTimeRatio", m_GTPartition0DeadTimeRatio);
}
COND_SERIALIZATION_INSTANTIATE(L1TriggerScaler::Lumi);

template <class Archive>
void MixingInputConfig::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("t-", t_);
    ar & boost::serialization::make_nvp("an-", an_);
    ar & boost::serialization::make_nvp("dpfv-", dpfv_);
    ar & boost::serialization::make_nvp("dp-", dp_);
    ar & boost::serialization::make_nvp("moot-", moot_);
    ar & boost::serialization::make_nvp("ioot-", ioot_);
}
COND_SERIALIZATION_INSTANTIATE(MixingInputConfig);

template <class Archive>
void MixingModuleConfig::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("configs-", configs_);
    ar & boost::serialization::make_nvp("minb-", minb_);
    ar & boost::serialization::make_nvp("maxb-", maxb_);
    ar & boost::serialization::make_nvp("bs-", bs_);
}
COND_SERIALIZATION_INSTANTIATE(MixingModuleConfig);

template <class Archive>
void RunInfo::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("m-run", m_run);
    ar & boost::serialization::make_nvp("m-start-time-ll", m_start_time_ll);
    ar & boost::serialization::make_nvp("m-start-time-str", m_start_time_str);
    ar & boost::serialization::make_nvp("m-stop-time-ll", m_stop_time_ll);
    ar & boost::serialization::make_nvp("m-stop-time-str", m_stop_time_str);
    ar & boost::serialization::make_nvp("m-fed-in", m_fed_in);
    ar & boost::serialization::make_nvp("m-start-current", m_start_current);
    ar & boost::serialization::make_nvp("m-stop-current", m_stop_current);
    ar & boost::serialization::make_nvp("m-avg-current", m_avg_current);
    ar & boost::serialization::make_nvp("m-max-current", m_max_current);
    ar & boost::serialization::make_nvp("m-min-current", m_min_current);
    ar & boost::serialization::make_nvp("m-run-intervall-micros", m_run_intervall_micros);
    ar & boost::serialization::make_nvp("m-current", m_current);
    ar & boost::serialization::make_nvp("m-times-of-currents", m_times_of_currents);
}
COND_SERIALIZATION_INSTANTIATE(RunInfo);

template <class Archive>
void RunSummary::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("m-run", m_run);
    ar & boost::serialization::make_nvp("m-name", m_name);
    ar & boost::serialization::make_nvp("m-start-time-ll", m_start_time_ll);
    ar & boost::serialization::make_nvp("m-start-time-str", m_start_time_str);
    ar & boost::serialization::make_nvp("m-stop-time-ll", m_stop_time_ll);
    ar & boost::serialization::make_nvp("m-stop-time-str", m_stop_time_str);
    ar & boost::serialization::make_nvp("m-lumisections", m_lumisections);
    ar & boost::serialization::make_nvp("m-subdt-in", m_subdt_in);
    ar & boost::serialization::make_nvp("m-hltkey", m_hltkey);
    ar & boost::serialization::make_nvp("m-nevents", m_nevents);
    ar & boost::serialization::make_nvp("m-rate", m_rate);
}
COND_SERIALIZATION_INSTANTIATE(RunSummary);

template <class Archive>
void runinfo_test::RunNumber::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("m-runnumber", m_runnumber);
}
COND_SERIALIZATION_INSTANTIATE(runinfo_test::RunNumber);

template <class Archive>
void runinfo_test::RunNumber::Item::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("m-run", m_run);
    ar & boost::serialization::make_nvp("m-id-start", m_id_start);
    ar & boost::serialization::make_nvp("m-id-stop", m_id_stop);
    ar & boost::serialization::make_nvp("m-number", m_number);
    ar & boost::serialization::make_nvp("m-name", m_name);
    ar & boost::serialization::make_nvp("m-start-time-sll", m_start_time_sll);
    ar & boost::serialization::make_nvp("m-start-time-str", m_start_time_str);
    ar & boost::serialization::make_nvp("m-stop-time-sll", m_stop_time_sll);
    ar & boost::serialization::make_nvp("m-stop-time-str", m_stop_time_str);
    ar & boost::serialization::make_nvp("m-lumisections", m_lumisections);
    ar & boost::serialization::make_nvp("m-subdt-joined", m_subdt_joined);
    ar & boost::serialization::make_nvp("m-subdt-in", m_subdt_in);
}
COND_SERIALIZATION_INSTANTIATE(runinfo_test::RunNumber::Item);

