
#include "CondFormats/SiPixelObjects/src/headers.h"

#include <boost/serialization/base_object.hpp>
#include <boost/serialization/nvp.hpp>
#include <boost/serialization/export.hpp>

#include "CondFormats/Serialization/interface/Equal.h"
#include "CondFormats/Serialization/interface/Instantiate.h"

template <class Archive>
void CaenChannel::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("isOn", isOn);
    ar & boost::serialization::make_nvp("iMon", iMon);
    ar & boost::serialization::make_nvp("vMon", vMon);
}
COND_SERIALIZATION_INSTANTIATE(CaenChannel);

template <typename T>
template <class Archive>
void PixelDCSObject<T>::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("items", items);
}

template <typename T>
template <class Archive>
void PixelDCSObject<T>::Item::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("name", name);
    ar & boost::serialization::make_nvp("value", value);
}

template <class Archive>
void SiPixel2DTemplateDBObject::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("index-", index_);
    ar & boost::serialization::make_nvp("maxIndex-", maxIndex_);
    ar & boost::serialization::make_nvp("numOfTempl-", numOfTempl_);
    ar & boost::serialization::make_nvp("version-", version_);
    ar & boost::serialization::make_nvp("isInvalid-", isInvalid_);
    ar & boost::serialization::make_nvp("sVector-", sVector_);
    ar & boost::serialization::make_nvp("templ-ID", templ_ID);
}
COND_SERIALIZATION_INSTANTIATE(SiPixel2DTemplateDBObject);

template <class Archive>
void SiPixelCPEGenericErrorParm::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("errors-", errors_);
    ar & boost::serialization::make_nvp("errorsBinSize-", errorsBinSize_);
    ar & boost::serialization::make_nvp("version-", version_);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelCPEGenericErrorParm);

template <class Archive>
void SiPixelCPEGenericErrorParm::DbEntry::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("sigma", sigma);
    ar & boost::serialization::make_nvp("rms", rms);
    ar & boost::serialization::make_nvp("bias", bias);
    ar & boost::serialization::make_nvp("pix-height", pix_height);
    ar & boost::serialization::make_nvp("ave-Qclus", ave_Qclus);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelCPEGenericErrorParm::DbEntry);

template <class Archive>
void SiPixelCPEGenericErrorParm::DbEntryBinSize::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("partBin-size", partBin_size);
    ar & boost::serialization::make_nvp("sizeBin-size", sizeBin_size);
    ar & boost::serialization::make_nvp("alphaBin-size", alphaBin_size);
    ar & boost::serialization::make_nvp("betaBin-size", betaBin_size);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelCPEGenericErrorParm::DbEntryBinSize);

template <class Archive>
void SiPixelCalibConfiguration::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("fNTriggers", fNTriggers);
    ar & boost::serialization::make_nvp("fRowPattern", fRowPattern);
    ar & boost::serialization::make_nvp("fColumnPattern", fColumnPattern);
    ar & boost::serialization::make_nvp("fVCalValues", fVCalValues);
    ar & boost::serialization::make_nvp("fMode", fMode);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelCalibConfiguration);

template <class Archive>
void SiPixelDbItem::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("packedVal-", packedVal_);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelDbItem);

template <class Archive>
void SiPixelDisabledModules::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("theDisabledModules", theDisabledModules);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelDisabledModules);

template <class Archive>
void SiPixelFedCabling::serialize(Archive & ar, const unsigned int)
{
}
COND_SERIALIZATION_INSTANTIATE(SiPixelFedCabling);

template <class Archive>
void SiPixelFedCablingMap::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("SiPixelFedCabling", boost::serialization::base_object<SiPixelFedCabling>(*this));
    ar & boost::serialization::make_nvp("theVersion", theVersion);
    ar & boost::serialization::make_nvp("theMap", theMap);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelFedCablingMap);

template <class Archive>
void SiPixelFedCablingMap::Key::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("fed", fed);
    ar & boost::serialization::make_nvp("link", link);
    ar & boost::serialization::make_nvp("roc", roc);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelFedCablingMap::Key);

template <class Archive>
void SiPixelGainCalibration::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("v-pedestals", v_pedestals);
    ar & boost::serialization::make_nvp("indexes", indexes);
    ar & boost::serialization::make_nvp("minPed-", minPed_);
    ar & boost::serialization::make_nvp("maxPed-", maxPed_);
    ar & boost::serialization::make_nvp("minGain-", minGain_);
    ar & boost::serialization::make_nvp("maxGain-", maxGain_);
    ar & boost::serialization::make_nvp("numberOfRowsToAverageOver-", numberOfRowsToAverageOver_);
    ar & boost::serialization::make_nvp("nBinsToUseForEncoding-", nBinsToUseForEncoding_);
    ar & boost::serialization::make_nvp("deadFlag-", deadFlag_);
    ar & boost::serialization::make_nvp("noisyFlag-", noisyFlag_);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelGainCalibration);

template <class Archive>
void SiPixelGainCalibration::DetRegistry::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("detid", detid);
    ar & boost::serialization::make_nvp("ibegin", ibegin);
    ar & boost::serialization::make_nvp("iend", iend);
    ar & boost::serialization::make_nvp("ncols", ncols);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelGainCalibration::DetRegistry);

template <class Archive>
void SiPixelGainCalibrationForHLT::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("v-pedestals", v_pedestals);
    ar & boost::serialization::make_nvp("indexes", indexes);
    ar & boost::serialization::make_nvp("minPed-", minPed_);
    ar & boost::serialization::make_nvp("maxPed-", maxPed_);
    ar & boost::serialization::make_nvp("minGain-", minGain_);
    ar & boost::serialization::make_nvp("maxGain-", maxGain_);
    ar & boost::serialization::make_nvp("pedPrecision", pedPrecision);
    ar & boost::serialization::make_nvp("gainPrecision", gainPrecision);
    ar & boost::serialization::make_nvp("numberOfRowsToAverageOver-", numberOfRowsToAverageOver_);
    ar & boost::serialization::make_nvp("nBinsToUseForEncoding-", nBinsToUseForEncoding_);
    ar & boost::serialization::make_nvp("deadFlag-", deadFlag_);
    ar & boost::serialization::make_nvp("noisyFlag-", noisyFlag_);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelGainCalibrationForHLT);

template <class Archive>
void SiPixelGainCalibrationForHLT::DetRegistry::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("detid", detid);
    ar & boost::serialization::make_nvp("ibegin", ibegin);
    ar & boost::serialization::make_nvp("iend", iend);
    ar & boost::serialization::make_nvp("ncols", ncols);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelGainCalibrationForHLT::DetRegistry);

template <class Archive>
void SiPixelGainCalibrationOffline::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("v-pedestals", v_pedestals);
    ar & boost::serialization::make_nvp("indexes", indexes);
    ar & boost::serialization::make_nvp("minPed-", minPed_);
    ar & boost::serialization::make_nvp("maxPed-", maxPed_);
    ar & boost::serialization::make_nvp("minGain-", minGain_);
    ar & boost::serialization::make_nvp("maxGain-", maxGain_);
    ar & boost::serialization::make_nvp("numberOfRowsToAverageOver-", numberOfRowsToAverageOver_);
    ar & boost::serialization::make_nvp("nBinsToUseForEncoding-", nBinsToUseForEncoding_);
    ar & boost::serialization::make_nvp("deadFlag-", deadFlag_);
    ar & boost::serialization::make_nvp("noisyFlag-", noisyFlag_);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelGainCalibrationOffline);

template <class Archive>
void SiPixelGainCalibrationOffline::DetRegistry::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("detid", detid);
    ar & boost::serialization::make_nvp("ibegin", ibegin);
    ar & boost::serialization::make_nvp("iend", iend);
    ar & boost::serialization::make_nvp("ncols", ncols);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelGainCalibrationOffline::DetRegistry);

template <class Archive>
void SiPixelGenErrorDBObject::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("index-", index_);
    ar & boost::serialization::make_nvp("maxIndex-", maxIndex_);
    ar & boost::serialization::make_nvp("numOfTempl-", numOfTempl_);
    ar & boost::serialization::make_nvp("version-", version_);
    ar & boost::serialization::make_nvp("isInvalid-", isInvalid_);
    ar & boost::serialization::make_nvp("sVector-", sVector_);
    ar & boost::serialization::make_nvp("templ-ID", templ_ID);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelGenErrorDBObject);

template <class Archive>
void SiPixelLorentzAngle::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("m-LA", m_LA);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelLorentzAngle);

template <class Archive>
void SiPixelPedestals::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("m-pedestals", m_pedestals);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelPedestals);

template <class Archive>
void SiPixelPerformanceSummary::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("timeStamp-", timeStamp_);
    ar & boost::serialization::make_nvp("runNumber-", runNumber_);
    ar & boost::serialization::make_nvp("luminosityBlock-", luminosityBlock_);
    ar & boost::serialization::make_nvp("numberOfEvents-", numberOfEvents_);
    ar & boost::serialization::make_nvp("allDetSummaries-", allDetSummaries_);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelPerformanceSummary);

template <class Archive>
void SiPixelPerformanceSummary::DetSummary::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("detId-", detId_);
    ar & boost::serialization::make_nvp("performanceValues-", performanceValues_);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelPerformanceSummary::DetSummary);

template <class Archive>
void SiPixelQuality::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("theDisabledModules", theDisabledModules);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelQuality);

template <class Archive>
void SiPixelQuality::disabledModuleType::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("DetID", DetID);
    ar & boost::serialization::make_nvp("errorType", errorType);
    ar & boost::serialization::make_nvp("BadRocs", BadRocs);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelQuality::disabledModuleType);

template <class Archive>
void SiPixelTemplateDBObject::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("index-", index_);
    ar & boost::serialization::make_nvp("maxIndex-", maxIndex_);
    ar & boost::serialization::make_nvp("numOfTempl-", numOfTempl_);
    ar & boost::serialization::make_nvp("version-", version_);
    ar & boost::serialization::make_nvp("isInvalid-", isInvalid_);
    ar & boost::serialization::make_nvp("sVector-", sVector_);
    ar & boost::serialization::make_nvp("templ-ID", templ_ID);
}
COND_SERIALIZATION_INSTANTIATE(SiPixelTemplateDBObject);

template <class Archive>
void sipixelobjects::PixelROC::serialize(Archive & ar, const unsigned int)
{
    ar & boost::serialization::make_nvp("theDetUnit", theDetUnit);
    ar & boost::serialization::make_nvp("theIdDU", theIdDU);
    ar & boost::serialization::make_nvp("theIdLk", theIdLk);
}
COND_SERIALIZATION_INSTANTIATE(sipixelobjects::PixelROC);

#include "CondFormats/SiPixelObjects/src/SerializationManual.h"
